@@ -1,5 +1,5 @@
-use sea_orm::{entity::prelude::*, Set};
 use sea_orm_migration::prelude::*;
+use sea_orm_migration::sea_orm::{entity::*, query::*};
 
 pub struct Migration;
 
@@ -19,8 +19,9 @@ impl MigrationTrait for Migration {
             ..Default::default()
         }
         .insert(db)
-        .await
-        .map(|_| ())
+        .await?;
+
+        Ok(())
     }
 
     async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
@@ -29,13 +30,14 @@ impl MigrationTrait for Migration {
         cake::Entity::delete_many()
             .filter(cake::Column::Name.eq("Cheesecake"))
             .exec(db)
-            .await
-            .map(|_| ())
+            .await?;
+
+        Ok(())
     }
 }
 
 mod cake {
-    use sea_orm::entity::prelude::*;
+    use sea_orm_migration::sea_orm::entity::prelude::*;
 
     #[derive(Clone, Debug, PartialEq, DeriveEntityModel)]
     #[sea_orm(table_name = "cake")]
